<?php
/**
* Custom Functions.
*
* @package Videocast
*/

if( !function_exists( 'videocast_sanitize_single_pagination_layout' ) ) :

    // Sidebar Option Sanitize.
    function videocast_sanitize_single_pagination_layout( $videocast_input ){

        $videocast_single_pagination = array( 'no-navigation','norma-navigation','ajax-next-post-load' );
        if( in_array( $videocast_input,$videocast_single_pagination ) ){

            return $videocast_input;

        }

        return;

    }

endif;

if( !function_exists( 'videocast_sanitize_archive_layout' ) ) :

    // Sidebar Option Sanitize.
    function videocast_sanitize_archive_layout( $videocast_input ){

        $videocast_archive_option = array( 'default','full','grid' );
        if( in_array( $videocast_input,$videocast_archive_option ) ){

            return $videocast_input;

        }

        return;

    }

endif;

if( !function_exists( 'videocast_sanitize_header_layout' ) ) :

    // Sidebar Option Sanitize.
    function videocast_sanitize_header_layout( $videocast_input ){

        $videocast_header_options = array( 'layout-1','layout-2','layout-3' );
        if( in_array( $videocast_input,$videocast_header_options ) ){

            return $videocast_input;

        }

        return;

    }

endif;

if( !function_exists( 'videocast_sanitize_single_post_layout' ) ) :

    // Single Layout Option Sanitize.
    function videocast_sanitize_single_post_layout( $videocast_input ){

        $videocast_single_layout = array( 'layout-1','layout-2' );
        if( in_array( $videocast_input,$videocast_single_layout ) ){

            return $videocast_input;

        }

        return;

    }

endif;

if ( ! function_exists( 'videocast_sanitize_checkbox' ) ) :

	/**
	 * Sanitize checkbox.
	 */
	function videocast_sanitize_checkbox( $videocast_checked ) {

		return ( ( isset( $videocast_checked ) && true === $videocast_checked ) ? true : false );

	}

endif;


if ( ! function_exists( 'videocast_sanitize_select' ) ) :

    /**
     * Sanitize select.
     */
    function videocast_sanitize_select( $videocast_input, $videocast_setting ) {

        // Ensure input is a slug.
        $videocast_input = sanitize_text_field( $videocast_input );

        // Get list of choices from the control associated with the setting.
        $choices = $videocast_setting->manager->get_control( $videocast_setting->id )->choices;

        // If the input is a valid key, return it; otherwise, return the default.
        return ( array_key_exists( $videocast_input, $choices ) ? $videocast_input : $videocast_setting->default );

    }

endif;

if ( ! function_exists( 'videocast_sanitize_positive_integer' ) ) :

    /**
     * Sanitize positive integer.
     *
     * @since 1.0.0
     *
     * @param int                  $input Number to sanitize.
     * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
     * @return int Sanitized number; otherwise, the setting default.
     */
    function videocast_sanitize_positive_integer( $input, $setting ) {

        $input = absint( $input );

        // If the input is an absolute integer, return it.
        // otherwise, return the default.
        return ( $input ? $input : $setting->default );

    }

endif;

if ( ! function_exists( 'videocast_sanitize_number_range' ) ) :

    /**
     * Sanitize number range.
     *
     * @since 1.0.0
     *
     * @see absint() https://developer.wordpress.org/reference/functions/absint/
     *
     * @param int                  $input Number to check within the numeric range defined by the setting.
     * @param WP_Customize_Setting $setting WP_Customize_Setting instance.
     * @return int|string The number, if it is zero or greater and falls within the defined range; otherwise, the setting default.
     */
    function videocast_sanitize_number_range( $input, $setting ) {

        // Ensure input is an absolute integer.
        $input = absint( $input );

        // Get the input attributes associated with the setting.
        $atts = $setting->manager->get_control( $setting->id )->input_attrs;

        // Get min.
        $min = ( isset( $atts['min'] ) ? $atts['min'] : $input );

        // Get max.
        $max = ( isset( $atts['max'] ) ? $atts['max'] : $input );

        // Get Step.
        $step = ( isset( $atts['step'] ) ? $atts['step'] : 1 );

        // If the input is within the valid range, return it; otherwise, return the default.
        return ( $min <= $input && $input <= $max && is_int( $input / $step ) ? $input : $setting->default );

    }

endif;
